# Slot: see_also


a reference

URI: [http://w3id.org/biolink/biolinkml/meta/see_also](slot_uri)
## Domain and Range

[Element](Element.md) -><sub>opt</sub> [[Uri](Uri.md)]
## Inheritance

## Children

## Used by

 * [ClassDefinition](ClassDefinition.md)
 * [Definition](Definition.md)
 * [Element](Element.md)
 * [SchemaDefinition](SchemaDefinition.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SubsetDefinition](SubsetDefinition.md)
 * [TypeDefinition](TypeDefinition.md)
